{**
 * lib/pkp/templates/frontend/components/header.tpl
 *
 * Copyright (c) 2014-2021 Simon Fraser University
 * Copyright (c) 2003-2021 John Willinsky
 * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
 *
 * @brief Common frontend site header.
 *
 * @uses $isFullWidth bool Should this page be displayed without sidebars? This
 *       represents a page-level override, and doesn't indicate whether or not
 *       sidebars have been configured for thesite.
 *}
{strip}
	{* Determine whether a logo or title string is being displayed *}
	{assign var="showingLogo" value=true}
	{if !$displayPageHeaderLogo}
		{assign var="showingLogo" value=false}
	{/if}
{/strip}
<!DOCTYPE html>
<html lang="{$currentLocale|replace:"_":"-"}" xml:lang="{$currentLocale|replace:"_":"-"}">
{if !$pageTitleTranslated}{capture assign="pageTitleTranslated"}{translate key=$pageTitle}{/capture}{/if}
{include file="frontend/components/headerHead.tpl"}
<body class="rbvb-template{if $isFullWidth} no-sidebar{/if}{if $isJournalPage} is-journal{/if} pkp_page_{$requestedPage|escape|default:"index"} pkp_op_{$requestedOp|escape|default:"index"}{if $showingLogo} has_site_logo{/if}" dir="{$currentLocaleLangDir|escape|default:"ltr"}">

	<div class="pkp_structure_page">

		{* Header *}
		<style>
			.rbvb-template header.pkp_structure_head { background-image: url('{$baseUrl}/plugins/themes/jdc/images/header-bg-min.jpg'); }
		</style>
		<header class="pkp_structure_head" id="headerNavigationContainer" role="banner">
			{* Skip to content nav links *}
			{include file="frontend/components/skipLinks.tpl"}

			<div class="pkp_head_wrapper">
				<div class="rbvb-top-menu">
					<div class="inner">
						<div class="flex-ai_center" style="gap: 10px;">
							{if $rbvbThemePlugin->getOption('pubContactEmail')}
								<div class="flex-ai_center">
									<span class="rbvb-icon material-symbols-rounded">mail</span>
									<a href="mailto:{$rbvbThemePlugin->getOption('pubContactEmail')}">
										{$rbvbThemePlugin->getOption('pubContactEmail')}
									</a>
								</div>
							{/if}
							{if $rbvbThemePlugin->getOption('pubContactPhone')}
								<div class="flex-ai_center">
								<span class="rbvb-icon material-symbols-rounded">call</span>
									<a href="tel:{$rbvbThemePlugin->getOption('pubContactPhone')}">
										{$rbvbThemePlugin->getOption('pubContactPhone')}
									</a>
								</div>
							{/if}
						</div>
						<div class="" id="navigationUserWrapper">
							{load_menu name="user" id="navigationUser" ulClass="rbvb-user-dropdown" liClass="profile"}
						</div>
					</div>
				</div>

				<div class="pkp_site_name_wrapper">
					{* <button class="pkp_site_nav_toggle">
						<span>Open Menu</span>
					</button> *}
					{if !$isJournalPage}
						<h1 class="pkp_screen_reader">
							{if $currentContext}
								{$displayPageHeaderTitle|escape}
							{else}
								{$siteTitle|escape}
							{/if}
						</h1>
					{/if}
					<div class="pkp_site_name">
						{capture assign="homeUrl"}
							{url page="index" router=$smarty.const.ROUTE_PAGE}
						{/capture}
						<div class="rbvb-header-content"> 
							<div class="rowA"> 
								{* ***** LOGO ***** *}
								<div class="">
									{if $displayPageHeaderLogo}
										<a href="{$homeUrl}" class="is_img">
											<img src="{$publicFilesDir}/{$displayPageHeaderLogo.uploadName|escape:"url"}" width="{$displayPageHeaderLogo.width|escape}" height="{$displayPageHeaderLogo.height|escape}" {if $displayPageHeaderLogo.altText != ''}alt="{$displayPageHeaderLogo.altText|escape}"{/if} />
										</a>
									{elseif $displayPageHeaderTitle}
										<a href="{$homeUrl}" class="is_text">{$displayPageHeaderTitle|escape}</a>
									{else}
										<a href="{$homeUrl}" class="is_img">
											<img src="{$baseUrl}/templates/images/structure/logo.png" alt="{$applicationName|escape}" title="{$applicationName|escape}" width="180" height="90" />
										</a>
									{/if}
									{if $rbvbThemePlugin->getOption('pubHeaderTitle')}
										<h1 class="header-title">
											{$rbvbThemePlugin->getOption('pubHeaderTitle')}
										</h1>
									{/if}
								</div>
								
								{* ***** LINKS ***** *}
								{if $rbvbThemePlugin->getOption('pubHeaderLinks')}
									<div class="links">
										{$rbvbThemePlugin->getPubHeaderLinks()}
									</div>
								{/if}

								{* ***** SEARH INPUT ***** *}
								<div class="search">
									{* isJournalPage *}
									{capture name="searchFormUrl"}{url escape=false}{/capture}
									{assign var=formUrlParameters value=[]}{* Prevent Smarty warning *}
									<form class="cmp_form" method="get" action="/index.php/{if $isJournalPage}{$currentContext->getPath()}{else}index{/if}/search/index">
										{foreach from=$formUrlParameters key=paramKey item=paramValue}
											<input type="hidden" name="{$paramKey|escape}" value="{$paramValue|escape}" />
										{/foreach}
										<div class="search_input">
											<span class="rbvb-icon material-symbols-rounded">search</span>
											{block name=searchQuery}
												<input type="text" id="query" name="query" value="{$query|escape}" class="query" placeholder="">
											{/block}
										</div>
										{* <div class="submit">
											<button class="submit" type="submit">{translate key="common.search"}</button>
										</div> *}
									</form>
								</div>
							</div>
							<div class="rowB">
								{if $rbvbThemePlugin->getOption('pubHeaderTitle')}
									<h1 class="header-title">
										{$rbvbThemePlugin->getOption('pubHeaderTitle')}
									</h1>
								{/if}
							</div>
						</div>
					</div>
				</div>

				{capture assign="primaryMenu"}
					{load_menu name="primary" id="navigationPrimary" ulClass="pkp_navigation_primary"}
				{/capture}

				<nav class="pkp_site_nav_menu" aria-label="{translate|escape key="common.navigation.site"}">
					<a id="siteNav"></a>
					<div class="pkp_navigation_primary_row">
						<div class="pkp_navigation_primary_wrapper">
							{* Primary navigation menu for current application *}
							{$primaryMenu}

							{* Search form *}
							{if $currentContext && $requestedPage !== 'search'}
								<div class="pkp_navigation_search_wrapper">
									<a href="{url page="search"}" class="pkp_search pkp_search_desktop">
										<span class="fa fa-search" aria-hidden="true"></span>
										{translate key="jdc.advancedSearch"}
									</a>
								</div>
							{/if}

						</div>
					</div>
				</nav>
			</div><!-- .pkp_head_wrapper -->
		</header><!-- .pkp_structure_head -->

		{* *********** MENU MOBILE *********** *}
		{include file="frontend/components/menuMobile.tpl"}

		{* *********** BANNER SLIDER *********** *}
		{if !$isJournalPage}
			{if !$requestedPage || $requestedPage === 'index'}
				<div id="jsdBanners" class="swiper">
					<div class="swiper-wrapper">
						<div class="swiper-slide">
							<img src="{$baseUrl}/plugins/themes/jdc/images/banners/banner-editorial.png" alt="">
						</div>
						<div class="swiper-slide">
							<img src="{$baseUrl}/plugins/themes/jdc/images/banners/banner-editorial.png" alt="">
						</div>
						<div class="swiper-slide">
							<img src="{$baseUrl}/plugins/themes/jdc/images/banners/banner-editorial.png" alt="">
						</div>
					</div>
					<div class="swiper-pagination"></div>
					<div class="swiper-button-prev"></div>
					<div class="swiper-button-next"></div>
					<div class="swiper-scrollbar"></div>
				</div>
			{/if}
		{/if}

		
		{* Wrapper for page content and sidebars *}
		{if $isFullWidth}
			{assign var=hasSidebar value=0}
		{/if}
		<div class="pkp_structure_content{if $hasSidebar} has_sidebar{/if}">
			{* ******** LANGUAGE TOGGLE ******** *}
			{if $supportedLocales|count > 1}
				<div class="rbvb-language-toggle">
					<div class="dropdown">
						<ul class="dropdown-menu">
							{foreach from=$supportedLocales key=localeKey item=localeName}
								{if $localeKey != $currentLocale}
									<li class="locale_{$localeKey|escape}" lang="{$localeKey|replace:"_":"-"}">
										<a
											href="{url router=$smarty.const.ROUTE_PAGE page="user" op="setLocale" path=$localeKey source=$smarty.server.REQUEST_URI}">
											{* {$localeName|escape} *}
											{translate key="jdc.$localeKey"}
										</a>
									</li>
								{/if}
							{/foreach}
						</ul>
						<button class="dropdown-button"><span
								class="rbvb-current-lang">{translate key="jdc.$currentLocale"}</span><span
								class="rbvb-icon material-symbols-rounded">arrow_drop_down</span></button>
					</div>
				</div>
			{/if}
			<div class="pkp_structure_main" role="main">
				<a id="pkp_content_main"></a>
				<div class="maincontent-grid">
